LocalAddBufferContext

Struct LocalAddBufferContext 

pub struct LocalAddBufferContext {
    pub param_slot: usize,
    pub map: IndexMap<UOpKey, Arc<UOp>>,
    pub vars: HashMap<String, (Arc<UOp>, Option<i64>)>,
    pub range: usize,
    pub opts: Vec<ContiguousHint>,
}
Per-kernel context for tracking state during kernel splitting.

Based on LocalAddBufferContext. This is used within split_store for each individual kernel being created.

IMPORTANT: Uses IndexMap for map to maintain insertion order. This is critical because PARAM slot indices are assigned in the order patterns match, and kernel sources must be in the same order for correct buffer indexing during execution.

Fields

param_slot: usize

PARAM slot counter (dg)

map: IndexMap<UOpKey, Arc<UOp>>

Buffer → AFTER mapping (IndexMap maintains insertion order)

vars: HashMap<String, (Arc<UOp>, Option<i64>)>

Bound variables: name → (DEFINE_VAR UOp, optional bound value).

range: usize

Range renumber counter

opts: Vec<ContiguousHint>

Optimization hints extracted from CONTIGUOUS.opts (ctx.opts)

Implementations

Source

impl LocalAddBufferContext

pub fn new() -> Self

pub fn next_param_slot(&mut self) -> usize

Get next PARAM slot index (ctx.dg).

pub fn next_range(&mut self) -> usize

Get next range renumber index.

pub fn add_var(&mut self, var: Arc<UOp>, value: Option<i64>)

Track a bound variable with its DEFINE_VAR UOp and concrete value.

pub fn map_buffer(&mut self, buf: Arc<UOp>, after: Arc<UOp>)

Map a buffer to its AFTER wrapper.

pub fn has_buffer(&self, buf: &Arc<UOp>) -> bool

Check if buffer is already mapped.