pub fn optimize_kernel_with_config(
ast: Arc<UOp>,
renderer: &Renderer,
config: &OptimizerConfig,
) -> Arc<UOp>Expand description
Apply optimizations with explicit configuration.
Use this when you need explicit control over the optimization settings.
Note: For beam search strategy, this falls back to heuristics because
beam search requires a compile_and_time function from the runtime.
Use optimize_kernel_beam() for actual beam search optimization.